@@ -1,8 +1,8 @@
 import { useMemo } from 'react';
 
+import { t } from '@grafana/i18n';
 import { config } from '@grafana/runtime';
 import { SceneComponentProps, sceneGraph, SceneObjectBase } from '@grafana/scenes';
-import { t } from 'app/core/internationalization';
 import { shareDashboardType } from 'app/features/dashboard/components/ShareModal/utils';
 import { SceneShareTabState } from 'app/features/dashboard-scene/sharing/types';
 import { getDashboardSceneFor } from 'app/features/dashboard-scene/utils/utils';
